from teyespider.constants import DedupMethod
from teyespider.db.es import index_item
from teyespider.db.kafka import send_msg
from teyespider.db.mongo import get_col
from teyespider.db.sql import insert_item, get_item, update_item
from teyespider.utils.config import get_task_id, get_is_dedup, get_dedup_field, get_dedup_method


def save_item_mongo(item):
    col = get_col()

    # 赋值task_id
    item['task_id'] = get_task_id()

    # 是否开启去重
    is_dedup = get_is_dedup()

    if is_dedup == '1':
        # 去重
        dedup_field = get_dedup_field()
        dedup_method = get_dedup_method()
        if dedup_method == DedupMethod.OVERWRITE:
            # 覆盖
            if col.find_one({dedup_field: item[dedup_field]}):
                col.replace_one({dedup_field: item[dedup_field]}, item)
            else:
                col.save(item)
        elif dedup_method == DedupMethod.IGNORE:
            # 忽略
            col.save(item)
        else:
            # 其他
            col.save(item)
    else:
        # 不去重
        col.save(item)


def save_item_sql(item):
    # 是否开启去重
    is_dedup = get_is_dedup()

    # 赋值task_id
    item['task_id'] = get_task_id()

    if is_dedup == '1':
        # 去重
        dedup_field = get_dedup_field()
        dedup_method = get_dedup_method()
        if dedup_method == DedupMethod.OVERWRITE:
            # 覆盖
            if get_item(item, dedup_field):
                update_item(item, dedup_field)
            else:
                insert_item(item)
        elif dedup_method == DedupMethod.IGNORE:
            # 忽略
            insert_item(item)
        else:
            # 其他
            insert_item(item)
    else:
        # 不去重
        insert_item(item)


def save_item_kafka(item):
    item['task_id'] = get_task_id()
    send_msg(item)


def save_item_es(item):
    item['task_id'] = get_task_id()
    index_item(item)



import os

from pymongo import MongoClient

from teyespider.utils.config import get_data_source


def get_col():
    ds = get_data_source()

    if ds.get('type') is None:
        # default data source
        mongo_host = os.environ.get('CRAWLAB_MONGO_HOST') or 'localhost'
        mongo_port = int(os.environ.get('CRAWLAB_MONGO_PORT') or 27017) or 27017
        mongo_db = os.environ.get('CRAWLAB_MONGO_DB') or 'test'
        mongo_username = os.environ.get('CRAWLAB_MONGO_USERNAME') or ''
        mongo_password = os.environ.get('CRAWLAB_MONGO_PASSWORD') or ''
        mongo_authsource = os.environ.get('CRAWLAB_MONGO_AUTHSOURCE') or 'admin'
        collection = os.environ.get('CRAWLAB_COLLECTION') or 'test'
        mongo = MongoClient(
            host=mongo_host,
            port=mongo_port,
            username=mongo_username,
            password=mongo_password,
            authSource=mongo_authsource,
        )
        db = mongo.get_database(mongo_db)
        col = db.get_collection(collection)

        return col

    # specified mongo data source
    mongo = MongoClient(
        host=ds.get('host'),
        port=int(ds.get('port')),
        username=ds.get('username'),
        password=ds.get('password'),
        authSource=ds.get('auth_source') or 'admin',
    )
    collection = os.environ.get('CRAWLAB_COLLECTION') or 'test'
    db = mongo.get_database(ds.get('database'))
    col = db.get_collection(collection)
    return col



from setuptools import setup, find_packages

import teyespider.config

with open('README.md', 'r') as f:
    long_description = f.read()

setup(
    name='teyespider-sdk',
    version=teyespider.config.VERSION,
    packages=find_packages(),
    url='',
    license='BSD-3-Clause',
    author='',
    author_email='',
    description='Python SDK  ',
    long_description=long_description,
    long_description_content_type="text/markdown",
    scripts=[],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'Click==7.0',
        'requests==2.22.0',
        'prettytable==0.7.2',
        'scrapy==2.2.0',
        'pymongo==3.10.1',
        'pymysql==0.9.3',
        'psycopg2-binary==2.8.5',
        'kafka-python==2.0.1',
        'elasticsearch==7.8.0',
	'pathspec==0.8.0',
    ],
    entry_points={
        'console_scripts': [
            'teye-spider=teyespider:main'
        ]
    }
)



import json
import os
import unittest

from teyespider import save_item
from teyespider.db.sql import get_conn
from teyespider.utils.config import get_collection, get_dedup_field
from teyespider.constants import DedupMethod

os.environ['CRAWLAB_TASK_ID'] = 'test_task_id'
os.environ['CRAWLAB_COLLECTION'] = 'results2'
os.environ['CRAWLAB_IS_DEDUP'] = '1'
os.environ['CRAWLAB_DEDUP_FIELD'] = 'url'
os.environ['CRAWLAB_DEDUP_METHOD'] = DedupMethod.OVERWRITE
os.environ['CRAWLAB_DATA_SOURCE'] = json.dumps({
    'type': 'postgres',
    'host': 'localhost',
    'port': '5432',
    'database': 'postgres',
    'username': 'postgres',
    'password': 'postgres',
})

url = 'example.com'


class PostgresSaveItemTestCase(unittest.TestCase):
    def test_save_item(self):
        for i in range(10):
            save_item({'url': url, 'title': str(i)})
        dedup_field = get_dedup_field()
        table_name = get_collection()
        conn = get_conn()
        cursor = conn.cursor()
        cursor.execute(f'SELECT count(*) FROM {table_name} WHERE {dedup_field} = \'{url}\'')
        conn.commit()
        res = cursor.fetchone()
        assert res[0] == 1
        cursor.execute(f'SELECT url,title FROM {table_name} WHERE {dedup_field} = \'{url}\'')
        conn.commit()
        res = cursor.fetchone()
        assert res[1] == '9'
        cursor.execute(f'DELETE FROM {table_name} WHERE {dedup_field} = \'{url}\'')
        conn.commit()
        cursor.close()


if __name__ == '__main__':
    unittest.main()



from teyespider.utils import save_item_mongo
from teyespider.utils.config import get_task_id


class CrawlabMongoPipeline(object):
    def process_item(self, item, spider):
        item_dict = dict(item)
        item_dict['task_id'] = get_task_id()
        save_item_mongo(item_dict)

        return item
